@@ -30,6 +30,7 @@
 #include <QTemporaryFile>
 #include <QPointer>
 #include <QTime>
+#include <QElapsedTimer>
 
 #include "kiocoredebug.h"
 
@@ -38,13 +39,13 @@ using namespace KIO;
 ConnectionBackend::ConnectionBackend(Mode m, QObject *parent)
     : QObject(parent),
       state(Idle),
-      socket(0),
+      socket(nullptr),
       len(-1),
       cmd(0),
       signalEmitted(false),
       mode(m)
 {
-    localServer = 0;
+    localServer = nullptr;
 }
 
 ConnectionBackend::~ConnectionBackend()
@@ -149,13 +150,14 @@ bool ConnectionBackend::listenForRemote()
         address.clear();
         address.setScheme(QStringLiteral("local"));
         address.setPath(sockname);
+        socketfile.setAutoRemove(false);
         socketfile.remove(); // can't bind if there is such a file
 
         localServer = new KLocalSocketServer(this);
         if (!localServer->listen(sockname, KLocalSocket::UnixSocket)) {
             errorString = localServer->errorString();
             delete localServer;
-            localServer = 0;
+            localServer = nullptr;
             return false;
         }
 
@@ -166,7 +168,7 @@ bool ConnectionBackend::listenForRemote()
         if (!tcpServer->isListening()) {
             errorString = tcpServer->errorString();
             delete tcpServer;
-            tcpServer = 0;
+            tcpServer = nullptr;
             return false;
         }
 
@@ -196,7 +198,7 @@ bool ConnectionBackend::waitForIncomingTask(int ms)
     }
 
     // not enough data in the socket, so wait for more
-    QTime timer;
+    QElapsedTimer timer;
     timer.start();
 
     while (socket->state() == QAbstractSocket::ConnectedState && !signalEmitted &&
@@ -252,7 +254,7 @@ ConnectionBackend *ConnectionBackend::nextPendingConnection()
     }
 
     if (!newSocket) {
-        return 0;    // there was no connection...
+        return nullptr;    // there was no connection...
     }
 
     ConnectionBackend *result = new ConnectionBackend(Mode(mode));
@@ -292,13 +294,13 @@ void ConnectionBackend::socketReadyRead()
             while (*p == ' ') {
                 p++;
             }
-            len = strtol(p, 0L, 16);
+            len = strtol(p, nullptr, 16);
 
             p = buffer + 7;
             while (*p == ' ') {
                 p++;
             }
-            cmd = strtol(p, 0L, 16);
+            cmd = strtol(p, nullptr, 16);
 
             //qCDebug(KIO_CORE) << this << "Beginning of command" << hex << cmd << "of size" << len;
         }
